@@ -189,15 +189,15 @@ f1.3 <- traceplot(fitc270.1)
 f1.4 <- traceplot(fitfgm.1)
 f1.5 <- traceplot(fitfrank.1)
 
-draws <- as.array(brma.1, pars=c('MU'))
-f1.6 <- bayesplot::mcmc_trace(draws)
+#draws <- as.array(brma.1, pars=c('MU'))
+f1.6 <- rstan::stan_trace(brma.1, pars=c('MU'))
     
     
 
 ## ---- fig.width=8, fig.height=5------------------------------------------
 library(Rmisc)
 
-multiplot(f1.1$plot, f1.2$plot, f1.3$plot, f1.4$plot, f1.5$plot, f1.6, cols=2)
+multiplot(f1.1, f1.2, f1.3, f1.4, f1.5, f1.6, cols=2)
 
 
 ## ------------------------------------------------------------------------
@@ -431,11 +431,11 @@ f2.3 <- traceplot(fitc270.2)
 f2.4 <- traceplot(fitfgm.2)
 f2.5 <- traceplot(fitfrank.2)
 
-draws <- as.array(brma.2, pars=c('MU'))
-f2.6  <- bayesplot::mcmc_trace(draws)
+#draws <- as.array(brma.2, pars=c('MU'))
+f2.6  <- rstan::stan_trace(brma.2, pars=c('MU'))
 
 ## ---- fig.width=8, , fig.height=10---------------------------------------
-multiplot(f2.1$plot, f2.2$plot, f2.3$plot, f2.4$plot, f2.5$plot, f2.6, cols=2)
+multiplot(f2.1, f2.2, f2.3, f2.4, f2.5, f2.6, cols=2)
 
 
 ## ------------------------------------------------------------------------
